import { ShoppingBasket } from "@mui/icons-material"
import { Box, Button, Divider, Drawer, InputAdornment, List, ListItem, ListItemIcon, ListItemText, TextField } from "@mui/material"
import { useDispatch, useSelector } from "react-redux"
import { CartAdd, CartClear, CartDel, CartIncOne, CartSet } from "../store/cartSlice"

const Basket = (props) => {
    const {
        cartOpen,
        closeCart = Function.prototype,
    } = props

    const cartState = Object.values(useSelector(state => state.cart))

    const dispatch = useDispatch()

    const productsRender = ({product, count}) => {
        
        return (
        <ListItem key={product._id} sx={{display:"block"}}>
            <Box sx={{ margin: '10px 5px' }}>
                <div style={{ 
                    height: '50px',
                    width: '50px',
                    backgroundSize: 'contain',
                            backgroundRepeat: 'no-repeat',
                            backgroundPosition: 'center',
      backgroundImage: `url(${product?.images ? `http://shop-roles.node.ed.asmer.org.ua/${product.images[0].url}` : "https://archive.org/download/no-photo-available/no-photo-available.png" })` 
    }}></div>
                <div>{product.name}</div>
            </Box>
            <Box>
                <Button variant="outlined" size="small" onClick={()=> dispatch(CartAdd({product}))} sx={{height:"40px", margin: "3px"}}>+</Button>
                <TextField
                    sx={{height:"40px", margin: "3px"}}
                    size="small"
                    type="number"
                    value={count}
                    InputProps={{
                        endAdornment: <InputAdornment position="start">шт</InputAdornment>,
                        inputProps: { min: "1", step: "1" },
                    }}
                    onChange={(e) => dispatch(CartSet({product, count: e.target.value}))}
                >

                </TextField>
                <Button
                variant="outlined"
                size="small"
                onClick={() => dispatch(CartIncOne({product}))}
                disabled = {count <=1 ? true: false}
                sx={{height:"40px", margin: "3px"}}
                >-</Button>
                <Button variant="outlined" size="small" onClick={() => dispatch(CartDel({product}))} sx={{height:"40px", margin: "3px"}}>удалить</Button>
            </Box>
            <Divider />
        </ListItem>
    )
                    }

    {/* cartState.map((product) => (
                        <div key={Math.random()}>
                            <Box sx={{ margin: '10px 5px' }}>
                                <div>_id: {product._id}</div>
                                <div>name: {product.name}</div>
                                <div>количество: {product.count}</div>
                            </Box>
                            <Box>
                                <Button variant="outlined" size="small" onClick={() => dispatch(CartAdd(product))}>+</Button>
                                <TextField
                                    size="small"
                                    type="number"
                                    value={product.count}
                                    InputProps={{
                                        endAdornment: <InputAdornment position="start">шт</InputAdornment>,
                                    }}
                                    onChange={(e) => dispatch(CartSet(
                                        (() => {
                                            let result = { ...product, count: e.target.value }
                                            return result
                                        })
                                            ()))}
                                >

                                </TextField>
                                <Button variant="outlined" size="small" onClick={() => dispatch(CartIncOne(product))}>-</Button>
                                <Button variant="outlined" size="small" onClick={() => dispatch(CartDel(product))}>удалить</Button>
                            </Box>
                            <Divider />
                        </div>
                    )
                    ) */}

    return (
        <Drawer
            anchor="right"
            open={cartOpen}
            onClose={closeCart}
        >
            <List sx={{ width: "400px" }}>
                <ListItem>
                    <ListItemIcon>
                        <ShoppingBasket />
                    </ListItemIcon>
                    <ListItemText primary="Корзина" />
                    <Button variant="outlined" onClick={() => dispatch(CartClear())}>Очитить корзину</Button>
                </ListItem>
            </List>
            <Divider />

            <List>
            { cartState.length ? 
                cartState.map(productsRender) : <ListItem>Ваша корзина пока пуста! </ListItem>
            }
            </List>
        </Drawer>
    )
}

export default Basket