import { createApi } from '@reduxjs/toolkit/query/react'
import { gql } from 'graphql-request'
import {graphqlRequestBaseQuery} from '@rtk-query/graphql-request-base-query'

export const categoriesApi = createApi({
    reducerPath: 'categoriesApi',
    baseQuery: graphqlRequestBaseQuery({ 
      url: 'http://shop-roles.node.ed.asmer.org.ua/graphql',
      prepareHeaders:(headers, { getState }) => {
        // By default, if we have a token in the store, let's use that for authenticated requests
        const token = getState().auth.token;
        if (token) {
            headers.set("Authorization", `Bearer ${token}`);
        }
        return headers;
    }
    }),
    endpoints: (builder) => ({
        getCategories: builder.query({
            query: () => ({
                document: gql`query baseCategory($searchNullparent: String){
                    CategoryFind(query: $searchNullparent){
                      _id name parent {
                        _id
                        name
                      }
                    }
                  }`,
                variables: {
                    searchNullparent: JSON.stringify([{parent: null}]),
                 },
            })
        }),
        getCategory: builder.query({
            query: (_id) => ({
                document: gql`query CategoryFindOne($qCategoryId: String) {
                        CategoryFindOne(query: $qCategoryId){
                          _id
                          name
                          parent{
                            _id
                            name
                          }
                          subCategories{
                            _id
                            name
                            goods{
                              _id
                              name
                            }
                          }
                          goods{
                            _id name price 
                            images {
                              url
                            }
                          }
                        }
                      }`,
                variables: {
                    qCategoryId: JSON.stringify([{ _id }])
                }
            })
        }),
        getProduct: builder.query({
            query: (_id) => ({
                document: gql`query oneProduct($GoodId: String){
                    GoodFindOne(query: $GoodId){
                      _id
                      description
                      name
                      price
                      categories{
                        name
                      }
                      images{
                        url
                      }
                    }  
                  }`,
                variables: {
                    GoodId: JSON.stringify( [{ _id }] )
                }
            })
        }),
        getLogin: builder.mutation({
            query: ({login, password}) => ({
                document: gql`query login($login:String, $password:String){
                    login(login:$login, password:$password)
                  }`,
                variables: {
                    login,
                    password
                }
            })
        }),
        getUser: builder.query({
          query: (_id) => ({
              document: gql`query oneUser($UserId: String){
                UserFindOne(query: $UserId){
                    _id
                    login
                    nick
                    avatar
                    
                  }
                }`,
              variables: {
                UserId: JSON.stringify( [{ _id }] )
              }
          })
      }),
      getUserById: builder.query({
        query: (_id) => ({
            document: gql`
                query GetUser($q: String) {
                    UserFindOne(query: $q) {
                        _id
                        login
                        nick
                        avatar { url }
                    }
                }
            `,
            variables: {q: JSON.stringify([{_id}])}
        }),
        providesTags: (result, error, id) =>  ( [{ type: 'User', id}])
    }),
    })
})

export const {
  useGetCategoriesQuery,
  useGetCategoryQuery,
  useGetProductQuery,
  useGetLoginMutation,
  useGetUserQuery,
  useGetUserByIdQuery
} = categoriesApi

